\name{geese-internal}
\alias{crossutri}
\alias{genZcor}
\alias{genZodds}
\title{Internal geese functions}
\description{
  Internal functions called by other functions.
}
\usage{
crossutri(wave)
genZcor(clusz, waves, corstrv)
genZodds(clusz, waves, corstrv, ncat)
}
\details{
  These are not to be called directly by the user.
}
\keyword{internal}
\eof
\name{geese}
\alias{geese}
\alias{geese.fit}
\alias{print.geese}
\alias{summary.geese}
\alias{print.summary.geese}
\title{Function to solve a Generalized Estimating Equation Model}
\description{
  Produces an object of class `geese' which is a Generalized Estimating
  Equation fit of the data.
}
\usage{
geese(formula = formula(data), sformula = ~1, id, waves = NULL,
      data = parent.frame(), subset = NULL, na.action = na.omit,
      contrasts = NULL, weights = NULL, zcor = NULL, corp = NULL,
      control = geese.control(...), b = NA, alpha = NA, gm = NA,
      family = gaussian(), mean.link = NULL, variance = NULL,
      cor.link = "identity", sca.link = "identity", link.same = TRUE,
      scale.fix = F, scale.value = 1, corstr = "independence", ...)

geese.fit(x, y, id, offset = rep(0, N), soffset = rep(0, N),
          weights = rep(1,N), waves = NULL, zsca = matrix(1, N, 1),
          zcor = NULL, corp = NULL, control = geese.control(...),
          b = NA, alpha = NA, gm = NA, family = gaussian(),
          mean.link = NULL, variance = NULL, cor.link = "identity",
          sca.link = "identity", link.same = TRUE, scale.fix = F,
          scale.value = 1, corstr = "independence", ...)
}
\arguments{
  \item{formula}{a formula expression as for \code{glm}, of the form
    \code{response ~ predictors}. See the documentation of lm and
    formula for details. As for glm, this specifies the linear predictor
    for modeling the mean. A term of the form \code{offset(expression)}
    is allowed.
  }
  \item{sformula}{a formula expression of the form \code{ ~ predictor},
    the response being ignored. This specifies the linear predictor for
    modeling the dispersion. A term of the form
    \code{offset(expression)} is allowed.
  }
  \item{id}{a vector which identifies the clusters.  The length of `id'
    should be the same as the number of observations.  Data are assumed
    to be sorted so that observations on a cluster are contiguous rows
    for all entities in the formula.
  }
  \item{waves}{an integer vector which identifies components in
    clusters. The length of \code{waves} should be the same as the
    number of observation. components with the same \code{waves} value
    will have the same link functions. 
  }
  \item{data}{
    an optional data frame in which to interpret the variables occurring
    in the \code{formula}, along with the \code{id} and \code{n} variables.
  }
  \item{subset}{
    expression saying which subset of the rows of the data should be used
    in the fit.  This can be a logical vector (which is replicated to have
    length equal to the number of observations), or a numeric vector
    indicating which observation numbers are to be included, or a
    character vector of the row names to be included.
    All observations are included by default.
  }
  \item{na.action}{
    a function to filter missing data.  For \code{gee} only \code{na.omit}
    should be used here.
  }
  \item{contrasts}{
    a list giving contrasts for some or all of the factors appearing
    in the model formula.  The elements of the list should have the
    same name as the variable and should be either a contrast matrix
    (specifically, any full-rank matrix with as many rows as there are
    levels in the factor), or else a function to compute such a matrix
    given the number of levels.
  }
  \item{weights}{an optional vector of weights to be used 
    in the fitting process. The length of \code{weights} should be the
    same as the number of observations. This weights is not (yet) the
    weight as in sas proc genmod, and hence is not recommended to use. 
  }
  \item{zcor}{a design matrix for correlation parameters.}
  \item{corp}{known parameters such as coordinates used for correlation
    coefficients.
  }
  \item{control}{a list of iteration and algorithmic constants. See
    \code{\link{geese.control}} for their names and default
    values. These can also be set as arguments to \code{geese} itself.
  }
  \item{b}{an initial estimate for the mean parameters.}
  \item{alpha}{an initial estimate for the correlation parameters.}
  \item{gm}{an initial estimate for the scale parameters.}
  \item{family}{a description of the error distribution and link
    function to be used in the model, as for \code{\link{glm}}.
  }
  \item{mean.link}{a character string specifying the link function for
    the means. The following are allowed:
    \code{"identity"}, \code{"logit"}, \code{"probit"},
    \code{"cloglog"}, \code{"log"}, and \code{"inverse"}.
    The default value is determined from family.
  }
  \item{variance}{a character string specifying the variance function
    in terms of the mean. The following are allowed:
    \code{"gaussian"}, \code{"binomial"}, \code{"poisson"}, and
    \code{"gamma"}. The default value is determined from family.
  }
  \item{cor.link}{a character string specifying the link function for
    the correlation coefficients. The following are allowed:
    \code{"identity"}, and \code{"fisherz"}.
  }
  \item{sca.link}{a character string specifying the link function for
    the scales. The following are allowed:
    \code{"identity"}, and \code{"log"}.
  }
  \item{link.same}{a logical indicating if all the components in a
    cluster should use the same link.
  }
  \item{scale.fix}{
    a logical variable; if true, the scale parameter is fixed at
    the value of \code{scale.value}.
  }
  \item{scale.value}{
    numeric variable giving the value to which the scale parameter
    should be fixed; used only if \code{scale.fix == TRUE}.
  }
  \item{corstr}{
    a character string specifying the correlation structure.
    The following are permitted:
    \code{"independence"},
    \code{"exchangeable"},
    \code{"ar1"},
    \code{"unstructured"} and
    \code{"userdefined"}
  }
  \item{x, y}{
    \code{x} is a design matrix of dimension \code{n * p}, and \code{y}
    is a vector of observations of length \code{n}.
  }
  \item{offset, soffset}{
    vector of offset for the mean and for the scale, respectively.
  }
  \item{zsca}{
    a design matrix of dimension \code{n * r} for the scales.
  }
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
  An object of class \code{"geese"} representing the fit.
}
\references{
  Liang, K.Y. and Zeger, S.L. (1986)
  Longitudinal data analysis using generalized linear models.
  \emph{Biometrika}, \bold{73} 13--22.

  Prentice, R.L. and Zhao, L.P. (1991).
  Estimating equations for parameters in means and covariances of
  multivariate discrete and continuous responses.
  \emph{Biometrics}, \bold{47} 825--839.
}
\author{Jun Yan \email{jyan@stat.uiowa.edu}}
\seealso{
  \code{\link{glm}}, \code{\link{lm}}, \code{\link{ordgee}}.
}
\examples{
data(seizure)
## Diggle, Liang, and Zeger (1994) pp166-168, compare Table 8.10
seiz.l <- reshape(seizure,
                  varying=list(c("base","y1", "y2", "y3", "y4")),
                  v.names="y", times=0:4, direction="long")
seiz.l <- seiz.l[order(seiz.l$id, seiz.l$time),]
seiz.l$t <- ifelse(seiz.l$time == 0, 8, 2)
seiz.l$x <- ifelse(seiz.l$time == 0, 0, 1)
m1 <- geese(y ~ offset(log(t)) + x + trt + x:trt, id = id,
            data=seiz.l, corstr="exch", family=poisson)
summary(m1)
m2 <- geese(y ~ offset(log(t)) + x + trt + x:trt, id = id,
            data = seiz.l, subset = id!=49,
            corstr = "exch", family=poisson)
summary(m2)

data(ohio)
fit <- geese(resp ~ age + smoke + age:smoke, id=id, data=ohio,
             family=binomial, corstr="exch", scale.fix=TRUE)
summary(fit)
fit.ar1 <- geese(resp ~ age + smoke + age:smoke, id=id, data=ohio,
                 family=binomial, corstr="ar1", scale.fix=TRUE)
summary(fit.ar1)

###### simulated data
## a function to generate a dataset
gendat <- function() {
  id <- gl(50, 4, 200)
  visit <- rep(1:4, 50)
  x1 <- rbinom(200, 1, 0.6) ## within cluster varying binary covariate
  x2 <- runif(200, 0, 1)   ## within cluster varying continuous covariate
  phi <- 1 + 2 * x1         ## true scale model
  ## the true correlation coefficient rho for an ar(1)
  ## correlation structure is 0.667.
  rhomat <- 0.667 ^ outer(1:4, 1:4, function(x, y) abs(x - y))
  chol.u <- chol(rhomat)
  noise <- as.vector(sapply(1:50, function(x) chol.u \%*\% rnorm(4)))
  e <- sqrt(phi) * noise
  y <- 1 + 3 * x1 - 2 * x2 + e
  dat <- data.frame(y, id, visit, x1, x2)
  dat
}

dat <- gendat()
fit <- geese(y ~ x1 + x2, id = id, data = dat, sformula = ~ x1,
             corstr = "ar1", jack = TRUE, j1s = TRUE, fij = TRUE)
summary(fit)


#### create user-defined design matrix of unstrctured correlation.
#### in this case, zcor has 4*3/2 = 6 columns, and 50 * 6 = 300 rows
zcor <- genZcor(clusz = rep(4, 50), waves = dat$visit, "unstr")
zfit <- geese(y ~ x1 + x2, id = id, data = dat, sformula = ~ x1,
              corstr = "userdefined", zcor = zcor,
              jack = TRUE, j1s = TRUE, fij = TRUE)
summary(zfit)

#### Now, suppose that we want the correlation of 1-2, 2-3, and 3-4
#### to be the same. Then zcor should have 4 columns.
z2 <- matrix(NA, 300, 4)
z2[,1] <- zcor[,1] + zcor[,4] + zcor[,6]
z2[,2:4] <- zcor[, c(2, 3, 5)]
summary(geese(y ~ x1 + x2, id = id, data = dat, sformula = ~ x1,
              corstr = "userdefined", zcor = z2,
              jack = TRUE, j1s = TRUE, fij = TRUE))

#### Next, we introduce non-constant cluster sizes by
#### randomly selecting 60 percent of the data
good <- sort(sample(1:nrow(dat), .6 * nrow(dat))) 
mdat <- dat[good,]

summary(geese(y ~ x1 + x2, id = id, data = mdat, waves = visit,
              sformula = ~ x1, corstr="ar1",
              jack = TRUE, j1s = TRUE, fij = TRUE))


}
\keyword{nonlinear}
\keyword{models}
\eof
\name{geese.control}
\alias{geese.control}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Auxiliary for Controlling GEE Fitting}
\description{
  Auxiliary function as user interface for `gee' fitting. Only used when
  calling `geese' or `geese.fit'.
}
\usage{
geese.control(epsilon = 1e-04, maxit = 25, trace = FALSE,
              scale.fix = FALSE, jack = FALSE, j1s = FALSE, fij = FALSE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{epsilon}{positive convergence tolerance epsilon; the iterations
    converge when the absolute value of the difference in parameter
    estimate is below \code{epsilon}.}
  \item{maxit}{integer giving the maximal number of Fisher Scoring iteration.}
  \item{trace}{logical indicating if output should be produced for each iteration.}
  \item{scale.fix}{logical indicating if the scale should be fixed.}
  \item{jack}{logical indicating if approximate jackknife variance
    estimate should be computed.}
  \item{j1s}{logical indicating if 1-step jackknife variance estimate
    should be computed.}
  \item{fij}{logical indicating if fully iterated jackknife variance
    estimate should be computed.}
}
\details{
  When `trace' is true, output for each iteration is printed to the
  screen by the c++ code. Hence, `options(digits = *)' does not control
  the precision.  
}
\value{
  A list with the arguments as components.
}
\author{Jun Yan \email{jyan@stat.uiowa.edu} }
\seealso{`geese.fit', the fitting procedure used by `geese'.}
\examples{
}
\keyword{optimize}
\keyword{models}
\eof
\name{koch}
\alias{koch}
\non_function{}
\title{Ordinal Data from Koch}
\usage{data(koch)}
\description{
The \code{koch} data frame has 288 rows and 4 columns.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{trt}{a numeric vector}
    \item{day}{a numeric vector}
    \item{y}{an ordered factor with levels:
      \code{1} < \code{2} < \code{3}}
    \item{id}{a numeric vector}
  }
}
\details{

}
\source{

}
\references{

}
\examples{
data(koch)
fit <- ordgee(y ~ trt + as.factor(day), id=id, data=koch, corstr="exch")
summary(fit)
}
\keyword{datasets}
\eof
\name{ohio}
\alias{ohio}
\non_function{}
\title{Ohio Children Wheeze Status}
\usage{data(ohio)}
\description{
The \code{ohio} data frame has 2148 rows and 4 columns. The dataset is a
subset of the six-city study, a longitudinal study of the health effects
of air pollution. 
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{resp}{an indicator of wheeze status (1=yes, 0=no)}
    \item{id}{a numeric vector for subject id}
    \item{age}{a numeric vector of age, 0 is 9 years old}
    \item{smoke}{an indicator of maternal smoking at the first year of
      the study}
  }
}
\references{
  Fitzmaurice, G.M. and Laird, N.M. (1993) A likelihood-based method for
  analyzing longitudinal binary responses, \emph{Biometrika} \bold{80}: 141--151.
}
\examples{
data(ohio)
fit <- geese(resp ~ age + smoke + age:smoke, id=id, data=ohio,
             family=binomial, corstr="exch", scale.fix=TRUE)
summary(fit)
fit.ar1 <- geese(resp ~ age + smoke + age:smoke, id=id, data=ohio,
                 family=binomial, corstr="ar1", scale.fix=TRUE)
summary(fit.ar1)
}
\keyword{datasets}
\eof
\name{ordgee}
\alias{ordgee}
\title{GEE for Clustered Ordinal Responses}
\description{
  Produces an object of class `geese' which is a Generalized Estimating
  Equation fit of the clustered ordinal data.
}
\usage{
ordgee(formula = formula(data), ooffset = NULL, id, waves = NULL,
       data = parent.frame, subset = NULL, na.action = na.omit,
       contrasts = NULL, weights = NULL, z = NULL,
       mean.link = "logit", corstr = "independence",
       control = geese.control(...), b = NA, alpha = NA,
       scale.fix = FALSE, scale.val = 1, int.const = TRUE,
       rev = FALSE,...)
}
\arguments{
  \item{formula}{a formula expression as for \code{glm}, of the form
    \code{response ~ predictors}. See the documentation of lm and
    formula for details. As for glm, this specifies the linear predictor
    for modelling the mean. A term of the form \code{offset(expression)}
    is allowed.
  }
  \item{ooffset}{vector of offset for the odds ratio model.}
  \item{id}{a vector which identifies the clusters.  The length of `id'
    should be the same as the number of observations.  Data are assumed
    to be sorted so that observations on a cluster are contiguous rows
    for all entities in the formula.}
  \item{waves}{an integer vector which identifies components in
    clusters. The length of \code{waves} should be the same as the
    number of observation. components with the same \code{waves} value
    will have the same link functions. }
  \item{data}{
        an optional data frame in which to interpret the variables occurring
    in the \code{formula}, along with the \code{id} and \code{n} variables.
  }
  \item{subset}{
    expression saying which subset of the rows of the data should be used
    in the fit.  This can be a logical vector (which is replicated to have
    length equal to the number of observations), or a numeric vector
    indicating which observation numbers are to be included, or a
    character vector of the row names to be included.
    All observations are included by default.
  }
  \item{na.action}{
    a function to filter missing data.  For \code{gee} only \code{na.omit}
    should be used here.
  }
  \item{contrasts}{
    a list giving contrasts for some or all of the factors appearing
    in the model formula.  The elements of the list should have the
    same name as the variable and should be either a contrast matrix
    (specifically, any full-rank matrix with as many rows as there are
    levels in the factor), or else a function to compute such a matrix
    given the number of levels.
  }
  \item{weights}{an optional vector of weights to be used
    in the fitting process. The length of \code{weights} should be the
    same as the number of observations.
  }
  \item{z}{a design matrix for the odds ratio model. The number of rows
    of z is \deqn{c^2 \sum n_i(n_i - 1)/2,} where \eqn{n_i} is the cluster
    size, and \eqn{c} is the number of categories minus 1.
  }
  \item{mean.link}{a character string specifying the link function for
    the means. The following are allowed:
    \code{"logit"}, \code{"probit"}, and \code{"cloglog"}.
  }
  \item{corstr}{a character string specifying the log odds. The
    following are allowed:
    \code{"independence"}, \code{"exchangeable"}, \code{"unstructured"},
    and \code{"userdefined"}.
  }
  \item{control}{a list of iteration and algorithmic constants. See
    \code{\link{geese.control}} for their names and default
    values. These can also be set as arguments to \code{geese} itself.
  }
  \item{b}{an initial estimate for the mean parameters.}
  \item{alpha}{an initial estimate for the odds ratio parameters.}
  \item{scale.fix}{a logical variable indicating if scale is fixed; it
    is set at TRUE currently.}
  \item{scale.val}{this argument is ignored currently.}
  \item{int.const}{a logical variable; if true, the intercepts are
    constant, and if false, the intercepts are different for different
    components in the response.}
  \item{rev}{a logical variable. For example, for a three level ordered
    response Y = 2, the accumulated indicator is coded as (1, 0, 0) if
    true and (0, 1, 1) if false.}
  \item{\dots}{further arguments passed to or from other methods.}
}
\value{
  An object of class \code{"geese"} representing the fit.
}
\references{
  Heagerty, P.J. and Zeger, S.L. (1996)
  Marginal regression models for clustered ordinal measurements.
  \emph{JASA}, \bold{91} 1024--1036.
}
\author{Jun Yan \email{jyan@stat.uiowa.edu}}
\seealso{
  \code{\link{glm}}, \code{\link{lm}}, \code{\link{geese}}.
}
\examples{
data(respdis)
resp.l <- reshape(respdis, varying =list(c("y1", "y2", "y3", "y4")),
                  v.names = "resp", direction = "long")
resp.l <- resp.l[order(resp.l$id, resp.l$time),]
fit <- ordgee(resp ~ trt, id=id, data=resp.l, int.const=FALSE)
summary(fit)

data(ohio)
ohio$resp <- as.factor(ohio$resp)
fit <- ordgee(resp ~ age + smoke + age:smoke, id = id, data=ohio)
summary(fit)
}
\keyword{nonlinear}
\keyword{models}
\eof
\name{respdis}
\alias{respdis}
\non_function{}
\title{Clustered Ordinal Respiratory Disorder}
\usage{data(respdis)}
\description{
The \code{respdis} data frame has 111 rows and 3 columns. The study
described in Miller et. al. (1993) is a randomized clinical trial of a
new treatment of respiratory disorder. The study was conducted in 111
patients who were randomly assigned to one of two treatments (active,
placebo). At each of four visits during the follow-up period, the
response status of each patients was classified on an ordinal scale.
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{y1, y2, y3, y4}{ordered factor measured at 4 visits for
      the response with levels, \code{1} < \code{2} < \code{3},
      1 = poor, 2 = good, and 3 = excellent}
    \item{trt}{a factor for treatment with levels, 1 = active, 0 =
      placebo.}
    }
}
\references{
Miller, M.E., David, C.S., and Landis, R.J. (1993) The analysis of
longitudinal polytomous data: Generalized estimating equation and
connections with weighted least squares, \emph{Biometrics} \bold{49}: 1033-1048.
}
\examples{
data(respdis)
resp.l <- reshape(respdis, varying = list(c("y1", "y2", "y3", "y4")),
                  v.names = "resp", direction = "long")
resp.l <- resp.l[order(resp.l$id, resp.l$time),]
fit <- ordgee(resp ~ trt, id = id, data = resp.l, int.const = FALSE)
summary(fit)

z <- model.matrix( ~ trt - 1, data = respdis)
ind <- rep(1:111, 4*3/2 * 2^2)
zmat <- z[ind,]
fit <- ordgee(resp ~ trt, id = id, data = resp.l, int.const = FALSE,
              z = zmat, corstr = "exchangeable")
summary(fit)
}
\keyword{datasets}
\eof
\name{seizure}
\alias{seizure}
\non_function{}
\title{Epiliptic Seizures}
\usage{data(seizure)}
\description{
The \code{seizure} data frame has 59 rows and 7 columns. The dataset
has the number of epiliptic seizures in each of four two-week intervals,
and in a baseline eight-week inverval, for treatment and control groups
with a total of 59 individuals. 
}
\format{
  This data frame contains the following columns:
  \describe{
    \item{y1}{the number of epiliptic seizures in the 1st 2-week
      interval}
    \item{y2}{the number of epiliptic seizures in the 2nd 2-week
      interval}
    \item{y3}{the number of epiliptic seizures in the 3rd 2-week
      interval}
    \item{y4}{the number of epiliptic seizures in the 4th 2-week
      interval}    
    \item{trt}{an indicator of treatment}
    \item{base}{the number of epilitic seizures in a baseline 8-week
      interval}
    \item{age}{a numeric vector of subject age}
  }
}
\source{
  Thall, P.F. and Vail S.C. (1990)
  Some covariance models for longitudinal count data with
  overdispersion. \emph{Biometrics} \bold{46}: 657--671.
}
\references{
  Diggle, P.J., Liang, K.Y., and Zeger, S.L. (1994)
  Analysis of Longitudinal Data. Clarendon Press.
}
\examples{
data(seizure)
## Diggle, Liang, and Zeger (1994) pp166-168, compare Table 8.10
seiz.l <- reshape(seizure,
                  varying=list(c("base","y1", "y2", "y3", "y4")),
                  v.names="y", times=0:4, direction="long")
seiz.l <- seiz.l[order(seiz.l$id, seiz.l$time),]
seiz.l$t <- ifelse(seiz.l$time == 0, 8, 2)
seiz.l$x <- ifelse(seiz.l$time == 0, 0, 1)
m1 <- geese(y ~ offset(log(t)) + x + trt + x:trt, id = id,
            data=seiz.l, corstr="exch", family=poisson)
summary(m1)
m2 <- geese(y ~ offset(log(t)) + x + trt + x:trt, id = id,
            data = seiz.l, subset = id!=49,
            corstr = "exch", family=poisson)
summary(m2)

## Thall and Vail (1990)
seiz.l <- reshape(seizure, varying=list(c("y1","y2","y3","y4")),
                  v.names="y", direction="long")
seiz.l <- seiz.l[order(seiz.l$id, seiz.l$time),]
seiz.l$lbase <- log(seiz.l$base / 4)
seiz.l$lage <- log(seiz.l$age)
seiz.l$v4 <- ifelse(seiz.l$time == 4, 1, 0)
m3 <- geese(y ~ lbase + trt + lbase:trt + lage + v4, 
            sformula = ~ as.factor(time) - 1, id = id,
            data = seiz.l, corstr = "exchangeable", family=poisson)
## compare to Model 13 in Table 4, noticeable difference
summary(m3)

## set up a design matrix for the correlation
z <- model.matrix(~ age, data = seizure)  # data is not seiz.l
## just to illustrate the scale link and correlation link
m4 <- geese(y ~ lbase + trt + lbase:trt + lage + v4,
            sformula = ~ as.factor(time)-1, id = id,
            data = seiz.l, corstr = "ar1", family = poisson,
            zcor = z, cor.link = "fisherz", sca.link = "log")
summary(m4)
}
\keyword{datasets}
\eof
\name{spruce}
\alias{spruce}
\non_function{}
\title{Log-size of 79 Sitka spruce trees}
\usage{data(spruce)}
\description{
The \code{spruce} data frame has 1027 rows and 6 columns. The data
consists of measurements on 79 sitka spruce trees over two growing
seasons. The trees were grown in four controlled environment chambers,
of which the first two, containing 27 trees each, were treated with
introduced ozone at 70 ppb whilst the remaining two, containing 12 and
13 trees, were controls.

}
\format{
  This data frame contains the following columns:
  \describe{
    \item{chamber}{a numeric vector of chamber numbers}
    \item{ozone}{a factor with levels \code{enriched} and \code{normal}}
    \item{id}{a numeric vector of tree id}
    \item{time}{a numeric vector of the time when the measurements were
      taken, measured in days since Jan. 1, 1988}
    \item{wave}{a numeric vector of the measurement number}
    \item{logsize}{a numeric vector of the log-size}
  }
}
\source{
  Diggle, P.J., Liang, K.Y., and Zeger, S.L. (1994) Analysis of Longitudinal
  Data, Clarendon Press.
}
\examples{
data(spruce)
spruce$contr <- ifelse(spruce$ozone=="enriched", 0, 1)
sitka88 <- spruce[spruce$wave <= 5,]
sitka89 <- spruce[spruce$wave > 5,]
fit.88 <- geese(logsize ~ as.factor(wave) + contr +
                          I(time/100*contr) - 1,
                id=id, data=sitka88, corstr="ar1")
summary(fit.88)

fit.89 <- geese(logsize ~ as.factor(wave) + contr - 1,
                id=id, data=sitka89, corstr="ar1")
summary(fit.89)
}
\keyword{datasets}
\eof
